Card class abstract

Constructors

Card([dynamic updates(CardBuilder b)])
factory

Properties

brand → Brand
no setter
cardholderName → String?
no setter
expirationMonth → int?
no setter
expirationYear → int?
no setter
hashCode → int
The hash code for this object.
no setterinherited
id → String?
no setter
lastFourDigits → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CardBuilder b)) → Card
Rebuilds the instance.
inherited
toBuilder() → CardBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Card>
no setter