CheckoutParameters class abstract

Constructors

CheckoutParameters([dynamic updates(CheckoutParametersBuilder b)])
factory

Properties

additionalPaymentTypes → BuiltList<AdditionalPaymentType>?
no setter
allowSplitTender → bool?
no setter
amountMoney → Money
no setter
collectSignature → bool?
no setter
delayCapture → bool?
no setter
hashCode → int
The hash code for this object.
no setterinherited
note → String?
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipReceipt → bool?
no setter
tipSettings → TipSettings?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CheckoutParametersBuilder b)) → CheckoutParameters
Rebuilds the instance.
inherited
toBuilder() → CheckoutParametersBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CheckoutParameters>
no setter