CheckoutParametersBuilder class

Constructors

CheckoutParametersBuilder()

Properties

additionalPaymentTypes ↔ ListBuilder<AdditionalPaymentType>
getter/setter pair
allowSplitTender ↔ bool?
getter/setter pair
amountMoney ↔ MoneyBuilder
getter/setter pair
collectSignature ↔ bool?
getter/setter pair
delayCapture ↔ bool?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
note ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
skipReceipt ↔ bool?
getter/setter pair
tipSettings ↔ TipSettingsBuilder
getter/setter pair

Methods

build() → _$CheckoutParameters
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(CheckoutParameters other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(CheckoutParametersBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited