CheckoutResult class abstract

Constructors

CheckoutResult([dynamic updates(CheckoutResultBuilder b)])
factory

Properties

createdAt → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
locationId → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tenders → BuiltList<Tender>
no setter
totalMoney → Money
no setter
totalTipMoney → Money
no setter
transactionClientId → String
no setter
transactionId → String?
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(CheckoutResultBuilder b)) → CheckoutResult
Rebuilds the instance.
inherited
toBuilder() → CheckoutResultBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<CheckoutResult>
no setter