CheckoutResultBuilder class

Constructors

CheckoutResultBuilder()

Properties

createdAt ↔ String?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
locationId ↔ String?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tenders ↔ ListBuilder<Tender>
getter/setter pair
totalMoney ↔ MoneyBuilder
getter/setter pair
totalTipMoney ↔ MoneyBuilder
getter/setter pair
transactionClientId ↔ String?
getter/setter pair
transactionId ↔ String?
getter/setter pair

Methods

build() → _$CheckoutResult
Builds.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
replace(CheckoutResult other) → void
Replaces the value in the builder with a new one.
override
toString() → String
A string representation of this object.
inherited
update(void updates(CheckoutResultBuilder)?) → void
Applies updates.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited