Location class abstract

Constructors

Location([dynamic updates(LocationBuilder b)])
factory

Properties

businessName → String
no setter
currencyCode → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
isCardProcessingActivated → bool
no setter
locationId → String
no setter
maximumCardPaymentAmountMoney → Money
no setter
minimumCardPaymentAmountMoney → Money
no setter
name → String
no setter
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(LocationBuilder b)) → Location
Rebuilds the instance.
inherited
toBuilder() → LocationBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Location>
no setter