Tender class abstract

Constructors

Tender([dynamic updates(TenderBuilder b)])
factory

Properties

cardDetails → CardDetails?
no setter
cashDetails → CashDetails?
no setter
createdAt → String
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tenderId → String?
no setter
tipMoney → Money
no setter
totalMoney → Money
no setter
type → TenderType
no setter

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
rebuild(dynamic updates(TenderBuilder b)) → Tender
Rebuilds the instance.
inherited
toBuilder() → TenderBuilder
Converts the instance to a builder B.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited

Static Properties

serializer → Serializer<Tender>
no setter