ReaderSdkException class

Implemented types

Constructors

ReaderSdkException(String _code, String? message, String debugCode, String? debugMessage)

Properties

code → ErrorCode?
no setter
debugCode → String
final
debugMessage → String?
final
hashCode → int
The hash code for this object.
no setterinherited
message → String?
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited